==> postLDAPadmin_frame-2.00.tar.gz: postldapadmin/htdocs/admin/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * index.php
 * 桼
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.1.1.1 $
 * $Date: 2010/04/22 01:52:47 $
 *
 **********************************************************/

include_once("lib/dglibcommon");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {

print <<<EOD
<form method="post" action="index.php" name="acc_mod_mf">
<center>
<table class="login">
    <tr>
        <td class="key1">桼̾</td>
        <td class="login">
            <input type="text" size=26 name="admin" maxlength="16">
        </td>
    </tr>
    <tr>
        <td class="key1">ѥ</td>
        <td class="login">
            <input type="password" name="passwd" maxlength="8">
        </td>
    </tr>
</table>
<br>
<input type="submit" name="login" value="">
</center>
</form>
EOD;
    }

    /***********************************************************
     * ̵֤ɽ
     **********************************************************/
    function display_tab() {
    }

    /***********************************************************
     * Ȥ̵ɽ
     **********************************************************/
    function display_logout() {
    }

};

/***********************************************************
 * 
 **********************************************************/
/* 󥹥󥹺 */
$pg = new my_page();

/* $basedir$topdirΥå */
url_search();

/* ɥᥤ */
$domain = $_SERVER['DOMAIN'];

if (read_web_conf(NULL) === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}


/***********************************************************
 * main
 **********************************************************/

/* ʬ */
if (isset($_POST["login"]) === TRUE) {

    /* ̾Υå */
    if (check_admin_uname($_POST["admin"], MAXADMINNAME) === TRUE &&
        check_passwd($_POST["passwd"], MINPASSWD, MAXADMINPASS) === TRUE) {
        /* åå& */
        if (sess_start($_POST["admin"], $_POST["passwd"], $sesskey) === TRUE) {
            result_log(":OK:󤷤ޤ");
            /* ֥եɹ */
            if (read_tab_conf() === FALSE) {
                $sys_err = TRUE;
                $pg->display(NULL);
                exit (1);
            }
            $script = key($tab_conf);
            $tab = key($tab_conf[$script][0]);
            dgp_location($script . "/" . $tab . "/index.php");
            exit (0);
        } else {
            $err_msg = "桼̾⤷ϥѥɤְäƤޤ";
        }
    } else {
        $err_msg = "桼̾⤷ϥѥɤޤ";
    }
}

if (isset($_GET["e"]) === TRUE) {
    if ($_GET["e"] == 1) {
        $err_msg = "å̵Ǥ";
    }
    if ($_GET["e"] == 2) {
        $err_msg = "ˡǤ";
    }
    if ($_GET["e"] == 3) {
        $err_msg = "LDAPФ³뤳ȤǤޤ";
    }
}

/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display(CONTENT);

?>

==> postLDAPadmin_frame-2.10.tar.gz: postldapadmin/htdocs/admin/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * index.php
 * 桼
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.2 $
 * $Date: 2010/06/10 05:12:31 $
 *
 **********************************************************/

include_once("lib/dglibcommon");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {

print <<<EOD
<form method="post" action="index.php" name="acc_mod_mf">
<center>
<table class="login">
    <tr>
        <td class="key1">桼̾</td>
        <td class="login">
            <input type="text" size=26 name="admin" maxlength="16">
        </td>
    </tr>
    <tr>
        <td class="key1">ѥ</td>
        <td class="login">
            <input type="password" name="passwd" maxlength="8">
        </td>
    </tr>
</table>
<br>
<input type="submit" value="" name="login" class="login_btn">
</center>
</form>
EOD;
    }

    /***********************************************************
     * ̵֤ɽ
     **********************************************************/
    function display_tab() {
    }

    /***********************************************************
     * Ȥ̵ɽ
     **********************************************************/
    function display_logout() {
    }

};

/***********************************************************
 * 
 **********************************************************/
/* 󥹥󥹺 */
$pg = new my_page();

/* $basedir$topdirΥå */
url_search();

/* ɥᥤ */
$domain = $_SERVER['DOMAIN'];

if (read_web_conf(NULL) === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/

/* ʬ */
if (isset($_POST["login"]) === TRUE) {

    /* ̾Υå */
    if (check_admin_uname($_POST["admin"], MAXADMINNAME) === TRUE &&
        check_passwd($_POST["passwd"], MINPASSWD, MAXADMINPASS) === TRUE) {
        /* åå& */
        if (sess_start($_POST["admin"], $_POST["passwd"], $sesskey) === TRUE) {
            result_log(":OK:󤷤ޤ");
            /* ֥եɹ */
            if (read_tab_conf() === FALSE) {
                $sys_err = TRUE;
                $pg->display(NULL);
                exit (1);
            }
            $script = key($tab_conf);
            $tab = key($tab_conf[$script][0]);
            dgp_location($script . "/" . $tab . "/index.php");
            exit (0);
        } else {
            $err_msg = "桼̾⤷ϥѥɤְäƤޤ";
        }
    } else {
        $err_msg = "桼̾⤷ϥѥɤޤ";
    }
}

if (isset($_GET["e"]) === TRUE) {
    if ($_GET["e"] == 1) {
        $err_msg = "å̵Ǥ";
    }
    if ($_GET["e"] == 2) {
        $err_msg = "ˡǤ";
    }
    if ($_GET["e"] == 3) {
        $err_msg = "LDAPФ³뤳ȤǤޤ";
    }
}

/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display(CONTENT);

?>
